@@ -1,4 +1,4 @@
-__version__ = '1.0.22'
+__version__ = '1.0.25'
 __author__ = 'arnold'
 
 import json
@@ -115,7 +115,8 @@ class TerraformQueryExtension(Extension):
         # passed in.
         for output in current_state_version_outputs:
             if(output["attributes"]["name"] == name):
-                if(value_name is not None):
+                if((value_name is not None) and (output["attributes"]["value"][value_name] is not None)):
                     return output["attributes"]["value"][value_name]
-                else:
-                    sys.exit("Value is None for attribute " +name) 
+                elif(output["attributes"]["value"] is not None):
+                    return output["attributes"]["value"]
+                sys.exit("Value is None for attribute " +name)
